@@ -3,7 +3,7 @@ package Module::Install::Admin::Makefile;
 use Module::Install::Base;
 @ISA = qw(Module::Install::Base);
 
-$VERSION = '0.64';
+$VERSION = '0.65';
 
 use strict 'vars';
 
@@ -21,7 +21,7 @@ sub postamble {
 realclean purge ::
 \t\$(RM_F) \$(DISTVNAME).tar\$(SUFFIX)
 \t\$(RM_RF) inc MANIFEST.bak _build
-\t\$(PERL) -I. -M$admin_class -e \"remove_meta()\"
+\t\$(PERL) -I. "-M$admin_class" -e "remove_meta()"
 
 reset :: purge
 
@@ -37,13 +37,17 @@ distsign ::
 END_MAKEFILE
 
     $self->{postamble} .= $text if defined $text;
-    $self->{postamble};
+
+    return $self->{postamble};
 }
 
 sub preop {
     my $self = shift;
+    my ($user_preop) = @_;
     my $admin_class = join('::', @{$self->_top}{qw(name dispatch)});
-    +{ PREOP => qq{\$(PERL) -I. -M$admin_class -e "dist_preop(q(\$(DISTVNAME)))"} }
+    $user_preop = qq{\$(PERL) -I. "-M$admin_class" -e "dist_preop(q(\$(DISTVNAME)))"} unless $user_preop;
+
+    return { PREOP => $user_preop }
 }
 
 1;
