@@ -13,7 +13,7 @@ use File::Spec ();
 
 use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.64';
+	$VERSION = '0.65';
 	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
@@ -69,7 +69,19 @@ sub cpanpm_config {
 
 # Are we currently running under the CPANPLUS client
 sub cpanplus {
-	!! $ENV{PERL5_CPANPLUS_IS_RUNNING};
+	my $script = File::Spec->rel2abs($0);
+	return !! (
+		$ENV{PERL5_CPANPLUS_IS_EXECUTING}
+		and
+		-f $script
+		and
+		$ENV{PERL5_CPANPLUS_IS_EXECUTING} eq $script
+	);
+}
+
+# Are we (maybe) running under a legacy version of CPANPLUS
+sub cpanplus_legacy {
+	!! $ENV{CPANPLUS_IS_RUNNING};
 }
 
 # Is CPANPLUS actually installed
@@ -77,20 +89,6 @@ sub cpanplus_available {
 	$_[0]->can_use('CPANPLUS');
 }
 
-# Get a cpanplus configuration key.
-# Assumes you have already check cpanplus is at least installed.
-sub cpanplus_config {
-	my $self = shift;
-
-	# Load the CPANPLUS configuration
-	require CPANPLUS::Configure;
-	my $conf = CPANPLUS::Configure->new
-		or die "Failed to load CPANPLUS configuration";
-
-	# Get the configuration key
-	return $conf->get_conf(shift);
-}
-
 # Are we currently running under some automated testing system
 sub automated_testing {
 	!! $ENV{AUTOMATED_TESTING};
